@@ -18,22 +18,21 @@ config = load_config()
 
 URL = 'https://github.com/fartuk/ml_investment/releases/download/weights/fair_marketcap_yahoo.pickle'
 OUT_NAME = 'fair_marketcap_yahoo'
-BAGGING_FRACTION = 0.7
-MODEL_CNT = 20
 FOLD_CNT = 5
 QUARTER_COUNTS = [1, 2, 4]
 CAT_COLUMNS = ['sector']
 QUARTER_COLUMNS = [
-    'quarterlyTotalRevenue',
-    'quarterlyNetIncome',
-    'quarterlyFreeCashFlow',
-    'quarterlyTotalAssets',
-    'quarterlyNetDebt',
-    'quarterlyGrossProfit',
-    'quarterlyWorkingCapital',
-    'quarterlyCashAndCashEquivalents',
-    'quarterlyResearchAndDevelopment',
-    'quarterlyCashDividendsPaid',
+    'totalRevenue',
+    'netIncome',
+    'cash',
+    'totalAssets',
+    'costOfRevenue',
+    'grossProfit',
+    'researchDevelopment',
+    'totalOperatingExpenses',
+    'ebit',
+    'totalLiab',
+    'discontinuedOperations',
 ]
 
 
@@ -71,16 +70,10 @@ def _create_target():
 
 
 def _create_model():
-    base_models = [LogExpModel(lgbm.sklearn.LGBMRegressor()),
-                   LogExpModel(ctb.CatBoostRegressor(verbose=False))]
-    
-    ensemble = EnsembleModel(base_models=base_models, 
-                             bagging_fraction=BAGGING_FRACTION,
-                             model_cnt=MODEL_CNT)
-        
-    model = GroupedOOFModel(base_model=ensemble,
-                            group_column='ticker',
-                            fold_cnt=FOLD_CNT)
+    model = GroupedOOFModel(
+                base_model=LogExpModel(ctb.CatBoostRegressor(verbose=False)),
+                group_column='ticker',
+                fold_cnt=FOLD_CNT)
 
     return model
 
@@ -121,7 +114,7 @@ def FairMarketcapYahoo(pretrained=True) -> Pipeline:
 
     if pretrained:
         if not os.path.exists(core_path):
-            print('Downloading model weights..')
+            print('Downloading pretrained model')
             urlretrieve(URL, core_path)       
         pipeline.load_core(core_path)
 
