@@ -18,28 +18,26 @@ from ml_investment.download_scripts import download_yahoo, download_daily_bars
 config = load_config()
 
 
-URL = 'https://github.com/fartuk/ml_investment/releases\
-      /download/weights/marketcap_down_std_yahoo.pickle'
+URL = 'https://github.com/fartuk/ml_investment/releases/download/weights/marketcap_down_std_yahoo.pickle'
 OUT_NAME = 'marketcap_down_std_yahoo'
 TARGET_HORIZON = 90
 MAX_BACK_QUARTER = 2
-BAGGING_FRACTION = 0.7
-MODEL_CNT = 20
 FOLD_CNT = 5
 QUARTER_COUNTS = [1, 2, 4]
 COMPARE_QUARTER_IDXS = [1, 4]
 CAT_COLUMNS = ["sector"]
 QUARTER_COLUMNS = [
-    'quarterlyTotalRevenue',
-    'quarterlyNetIncome',
-    'quarterlyFreeCashFlow',
-    'quarterlyTotalAssets',
-    'quarterlyNetDebt',
-    'quarterlyGrossProfit',
-    'quarterlyWorkingCapital',
-    'quarterlyCashAndCashEquivalents',
-    'quarterlyResearchAndDevelopment',
-    'quarterlyCashDividendsPaid',
+    'totalRevenue',
+    'netIncome',
+    'cash',
+    'totalAssets',
+    'costOfRevenue',
+    'grossProfit',
+    'researchDevelopment',
+    'totalOperatingExpenses',
+    'ebit',
+    'totalLiab',
+    'discontinuedOperations',
 ]
 
 
@@ -90,16 +88,10 @@ def _create_target():
 
 
 def _create_model():
-    base_models = [LogExpModel(lgbm.sklearn.LGBMRegressor()),
-                   LogExpModel(ctb.CatBoostRegressor(verbose=False))]
-                   
-    ensemble = EnsembleModel(base_models=base_models, 
-                             bagging_fraction=BAGGING_FRACTION,
-                             model_cnt=MODEL_CNT)
-
-    model = TimeSeriesOOFModel(base_model=ensemble,
-                               time_column='date',
-                               fold_cnt=FOLD_CNT)
+    model = TimeSeriesOOFModel(
+                base_model=LogExpModel(ctb.CatBoostRegressor(verbose=False)),
+                time_column='date',
+                fold_cnt=FOLD_CNT)
 
     return model
 
@@ -140,6 +132,7 @@ def MarketcapDownStdYahoo(pretrained=True) -> Pipeline:
 
     if pretrained:
         if not os.path.exists(core_path):
+            print('Downloading pretrained model')
             urlretrieve(URL, core_path)       
         pipeline.load_core(core_path)
 
@@ -160,5 +153,5 @@ def main():
 
 
 if __name__ == '__main__':
-   main() 
+    main() 
     
